@@ -143,13 +143,8 @@ attrs_build (CK_ATTRIBUTE *attrs,
 		}
 
 		memcpy (attr, add, sizeof (CK_ATTRIBUTE));
-		if (!take_values && attr->pValue != NULL) {
-			if (attr->ulValueLen == 0)
-				attr->pValue = malloc (1);
-			else
-				attr->pValue = memdup (attr->pValue, attr->ulValueLen);
-			return_val_if_fail (attr->pValue != NULL, NULL);
-		}
+		if (!take_values)
+			attr->pValue = memdup (attr->pValue, attr->ulValueLen);
 	}
 
 	/* Mark this as the end */
@@ -813,10 +808,10 @@ format_some_bytes (p11_buffer *buffer,
 	p11_buffer_add (buffer, "\"", 1);
 }
 
-static void
-format_attribute (p11_buffer *buffer,
-                  const CK_ATTRIBUTE *attr,
-                  CK_OBJECT_CLASS klass)
+void
+p11_attr_format (p11_buffer *buffer,
+                 const CK_ATTRIBUTE *attr,
+                 CK_OBJECT_CLASS klass)
 {
 	p11_buffer_add (buffer, "{ ", -1);
 	format_attribute_type (buffer, attr->type);
@@ -844,10 +839,10 @@ format_attribute (p11_buffer *buffer,
 	p11_buffer_add (buffer, " }", -1);
 }
 
-static void
-format_attributes (p11_buffer *buffer,
-                   const CK_ATTRIBUTE *attrs,
-                   int count)
+void
+p11_attrs_format (p11_buffer *buffer,
+                  const CK_ATTRIBUTE *attrs,
+                  int count)
 {
 	CK_BBOOL first = CK_TRUE;
 	CK_OBJECT_CLASS klass;
@@ -866,7 +861,7 @@ format_attributes (p11_buffer *buffer,
 		else
 			p11_buffer_add (buffer, ", ", 2);
 		first = CK_FALSE;
-		format_attribute (buffer, attrs + i, klass);
+		p11_attr_format (buffer, attrs + i, klass);
 	}
 	p11_buffer_add (buffer, " ]", -1);
 }
@@ -878,7 +873,7 @@ p11_attrs_to_string (const CK_ATTRIBUTE *attrs,
 	p11_buffer buffer;
 	if (!p11_buffer_init_null (&buffer, 128))
 		return_val_if_reached (NULL);
-	format_attributes (&buffer, attrs, count);
+	p11_attrs_format (&buffer, attrs, count);
 	return p11_buffer_steal (&buffer, NULL);
 }
 
@@ -889,6 +884,6 @@ p11_attr_to_string (const CK_ATTRIBUTE *attr,
 	p11_buffer buffer;
 	if (!p11_buffer_init_null (&buffer, 32))
 		return_val_if_reached (NULL);
-	format_attribute (&buffer, attr, klass);
+	p11_attr_format (&buffer, attr, klass);
 	return p11_buffer_steal (&buffer, NULL);
 }
