@@ -161,7 +161,7 @@ p11_mutex_init (p11_mutex_t *mutex)
 	int ret;
 
 	pthread_mutexattr_init (&attr);
-	pthread_mutexattr_settype (&attr, PTHREAD_MUTEX_RECURSIVE);
+	pthread_mutexattr_settype (&attr, PTHREAD_MUTEX_DEFAULT);
 	ret = pthread_mutex_init (mutex, &attr);
 	assert (ret == 0);
 	pthread_mutexattr_destroy (&attr);
@@ -192,7 +192,7 @@ p11_mmap_open (const char *path,
 	if (map == NULL)
 		return NULL;
 
-	map->fd = open (path, O_RDONLY | O_CLOEXEC);
+	map->fd = open (path, O_RDONLY);
 	if (map->fd == -1) {
 		free (map);
 		return NULL;
@@ -245,6 +245,12 @@ p11_dl_error (void)
 	return msg_buf;
 }
 
+void
+p11_dl_close (void *dl)
+{
+	FreeLibrary (dl);
+}
+
 int
 p11_thread_create (p11_thread_t *thread,
                    p11_thread_routine routine,
@@ -292,20 +298,14 @@ p11_mmap_open (const char *path,
 	p11_mmap *map;
 
 	map = calloc (1, sizeof (p11_mmap));
-	if (map == NULL) {
-		errno = ENOMEM;
+	if (map == NULL)
 		return NULL;
-	}
 
 	map->file  = CreateFile (path, GENERIC_READ, 0, NULL, OPEN_EXISTING, FILE_FLAG_RANDOM_ACCESS, NULL);
 	if (map->file == INVALID_HANDLE_VALUE) {
 		errn = GetLastError ();
 		free (map);
 		SetLastError (errn);
-		if (errn == ERROR_PATH_NOT_FOUND || errn == ERROR_FILE_NOT_FOUND)
-			errno = ENOENT;
-		else if (errn == ERROR_ACCESS_DENIED)
-			errno = EPERM;
 		return NULL;
 	}
 
@@ -314,8 +314,6 @@ p11_mmap_open (const char *path,
 		CloseHandle (map->file);
 		free (map);
 		SetLastError (errn);
-		if (errn == ERROR_ACCESS_DENIED)
-			errno = EPERM;
 		return NULL;
 	}
 
@@ -325,8 +323,6 @@ p11_mmap_open (const char *path,
 		CloseHandle (map->file);
 		free (map);
 		SetLastError (errn);
-		if (errn == ERROR_ACCESS_DENIED)
-			errno = EPERM;
 		return NULL;
 	}
 
@@ -338,8 +334,6 @@ p11_mmap_open (const char *path,
 		CloseHandle (map->file);
 		free (map);
 		SetLastError (errn);
-		if (errn == ERROR_ACCESS_DENIED)
-			errno = EPERM;
 		return NULL;
 	}
 
@@ -682,7 +676,7 @@ _gettemp (char *path,
 
 	for (;;) {
 		if (doopen) {
-			if ((*doopen = open (path, O_BINARY | O_CREAT | O_EXCL | O_RDWR | O_CLOEXEC, 0600)) >= 0)
+			if ((*doopen = open (path, O_BINARY | O_CREAT | O_EXCL | O_RDWR, 0600)) >= 0)
 				return (1);
 			if (errno != EEXIST)
 				return (0);
@@ -753,47 +747,3 @@ mkdtemp (char *template)
 }
 
 #endif /* HAVE_MKDTEMP */
-
-#ifndef HAVE_GETAUXVAL
-
-unsigned long
-getauxval (unsigned long type)
-{
-	static unsigned long secure = 0UL;
-	static bool check_secure_initialized = false;
-
-	/*
-	 * This is the only one our stand-in impl supports and is
-	 * also the only type we define in compat.h header
-	 */
-	assert (type == AT_SECURE);
-
-	if (!check_secure_initialized) {
-#if defined(HAVE_ISSETUGID)
-		secure = issetugid ();
-
-#elif defined(OS_UNIX)
-		uid_t ruid, euid, suid; /* Real, effective and saved user ID's */
-		gid_t rgid, egid, sgid; /* Real, effective and saved group ID's */
-
-#ifdef HAVE_GETRESUID
-		if (getresuid (&ruid, &euid, &suid) != 0 ||
-		    getresgid (&rgid, &egid, &sgid) != 0)
-#endif /* HAVE_GETRESUID */
-		{
-			suid = ruid = getuid ();
-			sgid = rgid = getgid ();
-			euid = geteuid ();
-			egid = getegid ();
-		}
-
-		secure = (ruid != euid || ruid != suid ||
-		          rgid != egid || rgid != sgid);
-#endif /* OS_UNIX */
-		check_secure_initialized = true;
-	}
-
-	return secure;
-}
-
-#endif /* HAVE_GETAUXVAL */
