@@ -68,10 +68,6 @@
 #define O_BINARY 0
 #endif
 
-#ifndef O_CLOEXEC
-#define O_CLOEXEC 0
-#endif
-
 #ifndef HAVE_GETPROGNAME
 const char * getprogname (void);
 #endif
@@ -139,13 +135,13 @@ typedef HMODULE dl_module_t;
 
 #define p11_dl_open(f) \
 	(LoadLibrary (f))
-#define p11_dl_close(d) \
-	(FreeLibrary (d))
 #define p11_dl_symbol(d, s) \
 	((void *)GetProcAddress ((d), (s)))
 
 char *    p11_dl_error       (void);
 
+void      p11_dl_close       (void * dl);
+
 #define p11_sleep_ms(ms) \
 	(Sleep (ms))
 
@@ -295,16 +291,4 @@ time_t      timegm          (struct tm *tm);
 
 #endif /* HAVE_TIMEGM */
 
-#ifdef HAVE_GETAUXVAL
-
-#include <sys/auxv.h>
-
-#else /* !HAVE_GETAUXVAL */
-
-unsigned long     getauxval (unsigned long type);
-
-#define AT_SECURE 23
-
-#endif /* !HAVE_GETAUXVAL */
-
 #endif /* __COMPAT_H__ */
