@@ -33,7 +33,7 @@
  */
 
 #include "config.h"
-#include "CuTest.h"
+#include "test.h"
 
 #define P11_KIT_FUTURE_UNSTABLE_API 1
 
@@ -49,17 +49,14 @@
 #include <stdlib.h>
 
 static CK_FUNCTION_LIST_PTR_PTR
-initialize_and_get_modules (CuTest *tc)
+initialize_and_get_modules (void)
 {
 	CK_FUNCTION_LIST_PTR_PTR modules;
-	CK_RV rv;
 
 	p11_message_quiet ();
 
-	rv = p11_kit_initialize_registered ();
-	CuAssertIntEquals (tc, CKR_OK, rv);
-	modules = p11_kit_registered_modules ();
-	CuAssertTrue (tc, modules != NULL && modules[0] != NULL);
+	modules = p11_kit_modules_load_and_initialize (0);
+	assert (modules != NULL && modules[0] != NULL);
 
 	p11_message_loud ();
 
@@ -67,14 +64,10 @@ initialize_and_get_modules (CuTest *tc)
 }
 
 static void
-finalize_and_free_modules (CuTest *tc,
-                           CK_FUNCTION_LIST_PTR_PTR modules)
+finalize_and_free_modules (CK_FUNCTION_LIST_PTR_PTR modules)
 {
-	CK_RV rv;
-
-	free (modules);
-	rv = p11_kit_finalize_registered ();
-	CuAssertIntEquals (tc, CKR_OK, rv);
+	p11_kit_modules_finalize (modules);
+	p11_kit_modules_release (modules);
 }
 
 static int
@@ -93,7 +86,7 @@ has_handle (CK_ULONG *objects,
 
 
 static void
-test_all (CuTest *tc)
+test_all (void)
 {
 	CK_OBJECT_HANDLE objects[128];
 	CK_FUNCTION_LIST_PTR *modules;
@@ -104,59 +97,60 @@ test_all (CuTest *tc)
 	CK_RV rv;
 	int at;
 
-	modules = initialize_and_get_modules (tc);
+	modules = initialize_and_get_modules ();
 
 	iter = p11_kit_iter_new (NULL);
 	p11_kit_iter_begin (iter, modules);
 
 	at = 0;
 	while ((rv = p11_kit_iter_next (iter)) == CKR_OK) {
-		CuAssertTrue (tc, at < 128);
+		assert (at < 128);
 		objects[at] = p11_kit_iter_get_object (iter);
 
 		module = p11_kit_iter_get_module (iter);
-		CuAssertPtrNotNull (tc, module);
+		assert_ptr_not_null (module);
 
 		session = p11_kit_iter_get_session (iter);
-		CuAssertTrue (tc, session != 0);
+		assert (session != 0);
 
 		/* Do something with the object */
 		size = 0;
 		rv = (module->C_GetObjectSize) (session, objects[at], &size);
-		CuAssertTrue (tc, rv == CKR_OK);
-		CuAssertTrue (tc, size > 0);
+		assert (rv == CKR_OK);
+		assert (size > 0);
 
 		at++;
 	}
 
-	CuAssertTrue (tc, rv == CKR_CANCEL);
+	assert (rv == CKR_CANCEL);
 
 	/* Three modules, each with 1 slot, and 3 public objects */
-	CuAssertIntEquals (tc, 9, at);
+	assert_num_eq (9, at);
 
-	CuAssertTrue (tc, has_handle (objects, at, MOCK_DATA_OBJECT));
-	CuAssertTrue (tc, !has_handle (objects, at, MOCK_PRIVATE_KEY_CAPITALIZE));
-	CuAssertTrue (tc, has_handle (objects, at, MOCK_PUBLIC_KEY_CAPITALIZE));
-	CuAssertTrue (tc, !has_handle (objects, at, MOCK_PRIVATE_KEY_PREFIX));
-	CuAssertTrue (tc, has_handle (objects, at, MOCK_PUBLIC_KEY_PREFIX));
+	assert (has_handle (objects, at, MOCK_DATA_OBJECT));
+	assert (!has_handle (objects, at, MOCK_PRIVATE_KEY_CAPITALIZE));
+	assert (has_handle (objects, at, MOCK_PUBLIC_KEY_CAPITALIZE));
+	assert (!has_handle (objects, at, MOCK_PRIVATE_KEY_PREFIX));
+	assert (has_handle (objects, at, MOCK_PUBLIC_KEY_PREFIX));
 
 	p11_kit_iter_free (iter);
 
-	finalize_and_free_modules (tc, modules);
+	finalize_and_free_modules (modules);
 }
 
 static CK_RV
 on_iter_callback (P11KitIter *iter,
-                      CK_BBOOL *matches,
-                      void *data)
+                  CK_BBOOL *matches,
+                  void *data)
 {
-	CuTest *tc = data;
 	CK_OBJECT_HANDLE object;
 	CK_FUNCTION_LIST_PTR module;
 	CK_SESSION_HANDLE session;
 	CK_ULONG size;
 	CK_RV rv;
 
+	assert_str_eq (data, "callback");
+
 	object = p11_kit_iter_get_object (iter);
 	if (object != MOCK_PUBLIC_KEY_CAPITALIZE && object != MOCK_PUBLIC_KEY_PREFIX) {
 		*matches = CK_FALSE;
@@ -164,22 +158,22 @@ on_iter_callback (P11KitIter *iter,
 	}
 
 	module = p11_kit_iter_get_module (iter);
-	CuAssertPtrNotNull (tc, module);
+	assert_ptr_not_null (module);
 
 	session = p11_kit_iter_get_session (iter);
-	CuAssertTrue (tc, session != 0);
+	assert (session != 0);
 
 	/* Do something with the object */
 	size = 0;
 	rv = (module->C_GetObjectSize) (session, object, &size);
-	CuAssertTrue (tc, rv == CKR_OK);
-	CuAssertTrue (tc, size > 0);
+	assert (rv == CKR_OK);
+	assert (size > 0);
 
 	return CKR_OK;
 }
 
 static void
-test_callback (CuTest *tc)
+test_callback (void)
 {
 	CK_OBJECT_HANDLE objects[128];
 	CK_FUNCTION_LIST_PTR *modules;
@@ -187,33 +181,33 @@ test_callback (CuTest *tc)
 	CK_RV rv;
 	int at;
 
-	modules = initialize_and_get_modules (tc);
+	modules = initialize_and_get_modules ();
 
 	iter = p11_kit_iter_new (NULL);
-	p11_kit_iter_add_callback (iter, on_iter_callback, tc, NULL);
+	p11_kit_iter_add_callback (iter, on_iter_callback, "callback", NULL);
 	p11_kit_iter_begin (iter, modules);
 
 	at= 0;
 	while ((rv = p11_kit_iter_next (iter)) == CKR_OK) {
-		CuAssertTrue (tc, at < 128);
+		assert (at < 128);
 		objects[at] = p11_kit_iter_get_object (iter);
 		at++;
 	}
 
-	CuAssertTrue (tc, rv == CKR_CANCEL);
+	assert (rv == CKR_CANCEL);
 
 	/* Three modules, each with 1 slot, and 2 public keys */
-	CuAssertIntEquals (tc, 6, at);
+	assert_num_eq (6, at);
 
-	CuAssertTrue (tc, !has_handle (objects, at, MOCK_DATA_OBJECT));
-	CuAssertTrue (tc, !has_handle (objects, at, MOCK_PRIVATE_KEY_CAPITALIZE));
-	CuAssertTrue (tc, has_handle (objects, at, MOCK_PUBLIC_KEY_CAPITALIZE));
-	CuAssertTrue (tc, !has_handle (objects, at, MOCK_PRIVATE_KEY_PREFIX));
-	CuAssertTrue (tc, has_handle (objects, at, MOCK_PUBLIC_KEY_PREFIX));
+	assert (!has_handle (objects, at, MOCK_DATA_OBJECT));
+	assert (!has_handle (objects, at, MOCK_PRIVATE_KEY_CAPITALIZE));
+	assert (has_handle (objects, at, MOCK_PUBLIC_KEY_CAPITALIZE));
+	assert (!has_handle (objects, at, MOCK_PRIVATE_KEY_PREFIX));
+	assert (has_handle (objects, at, MOCK_PUBLIC_KEY_PREFIX));
 
 	p11_kit_iter_free (iter);
 
-	finalize_and_free_modules (tc, modules);
+	finalize_and_free_modules (modules);
 }
 
 static CK_RV
@@ -225,30 +219,30 @@ on_callback_fail (P11KitIter *iter,
 }
 
 static void
-test_callback_fails (CuTest *tc)
+test_callback_fails (void)
 {
 	CK_FUNCTION_LIST_PTR *modules;
 	P11KitIter *iter;
 	CK_RV rv;
 	int at;
 
-	modules = initialize_and_get_modules (tc);
+	modules = initialize_and_get_modules ();
 
 	iter = p11_kit_iter_new (NULL);
-	p11_kit_iter_add_callback (iter, on_callback_fail, tc, NULL);
+	p11_kit_iter_add_callback (iter, on_callback_fail, "callback", NULL);
 	p11_kit_iter_begin (iter, modules);
 
 	at= 0;
 	while ((rv = p11_kit_iter_next (iter)) == CKR_OK)
 		at++;
 
-	CuAssertTrue (tc, rv == CKR_DATA_INVALID);
+	assert (rv == CKR_DATA_INVALID);
 
 	/* Shouldn't have succeeded at all */
-	CuAssertIntEquals (tc, 0, at);
+	assert_num_eq (0, at);
 
 	p11_kit_iter_free (iter);
-	finalize_and_free_modules (tc, modules);
+	finalize_and_free_modules (modules);
 }
 
 static void
@@ -259,7 +253,7 @@ on_destroy_increment (void *data)
 }
 
 static void
-test_callback_destroyer (CuTest *tc)
+test_callback_destroyer (void)
 {
 	P11KitIter *iter;
 	int value = 1;
@@ -268,11 +262,11 @@ test_callback_destroyer (CuTest *tc)
 	p11_kit_iter_add_callback (iter, on_callback_fail, &value, on_destroy_increment);
 	p11_kit_iter_free (iter);
 
-	CuAssertIntEquals (tc, 2, value);
+	assert_num_eq (2, value);
 }
 
 static void
-test_with_session (CuTest *tc)
+test_with_session (void)
 {
 	CK_OBJECT_HANDLE objects[128];
 	CK_SESSION_HANDLE session;
@@ -282,53 +276,54 @@ test_with_session (CuTest *tc)
 	CK_RV rv;
 	int at;
 
-	rv = p11_kit_initialize_module (&mock_module);
-	CuAssertTrue (tc, rv == CKR_OK);
+	mock_module_reset ();
+	rv = mock_module.C_Initialize (NULL);
+	assert (rv == CKR_OK);
 
 	rv = mock_C_OpenSession (MOCK_SLOT_ONE_ID, CKF_SERIAL_SESSION, NULL, NULL, &session);
-	CuAssertTrue (tc, rv == CKR_OK);
+	assert (rv == CKR_OK);
 
 	iter = p11_kit_iter_new (NULL);
 	p11_kit_iter_begin_with (iter, &mock_module, 0, session);
 
 	at= 0;
 	while ((rv = p11_kit_iter_next (iter)) == CKR_OK) {
-		CuAssertTrue (tc, at < 128);
+		assert (at < 128);
 		objects[at] = p11_kit_iter_get_object (iter);
 
 		slot = p11_kit_iter_get_slot (iter);
-		CuAssertTrue (tc, slot == MOCK_SLOT_ONE_ID);
+		assert (slot == MOCK_SLOT_ONE_ID);
 
 		module = p11_kit_iter_get_module (iter);
-		CuAssertPtrEquals (tc, module, &mock_module);
+		assert_ptr_eq (module, &mock_module);
 
-		CuAssertTrue (tc, session == p11_kit_iter_get_session (iter));
+		assert (session == p11_kit_iter_get_session (iter));
 		at++;
 	}
 
-	CuAssertTrue (tc, rv == CKR_CANCEL);
+	assert (rv == CKR_CANCEL);
 
 	/* 1 modules, each with 1 slot, and 3 public objects */
-	CuAssertIntEquals (tc, 3, at);
+	assert_num_eq (3, at);
 
-	CuAssertTrue (tc, has_handle (objects, at, MOCK_DATA_OBJECT));
-	CuAssertTrue (tc, !has_handle (objects, at, MOCK_PRIVATE_KEY_CAPITALIZE));
-	CuAssertTrue (tc, has_handle (objects, at, MOCK_PUBLIC_KEY_CAPITALIZE));
-	CuAssertTrue (tc, !has_handle (objects, at, MOCK_PRIVATE_KEY_PREFIX));
-	CuAssertTrue (tc, has_handle (objects, at, MOCK_PUBLIC_KEY_PREFIX));
+	assert (has_handle (objects, at, MOCK_DATA_OBJECT));
+	assert (!has_handle (objects, at, MOCK_PRIVATE_KEY_CAPITALIZE));
+	assert (has_handle (objects, at, MOCK_PUBLIC_KEY_CAPITALIZE));
+	assert (!has_handle (objects, at, MOCK_PRIVATE_KEY_PREFIX));
+	assert (has_handle (objects, at, MOCK_PUBLIC_KEY_PREFIX));
 
 	p11_kit_iter_free (iter);
 
 	/* The session is still valid ... */
 	rv = mock_module.C_CloseSession (session);
-	CuAssertTrue (tc, rv == CKR_OK);
+	assert (rv == CKR_OK);
 
-	rv = p11_kit_finalize_module (&mock_module);
-	CuAssertTrue (tc, rv == CKR_OK);
+	rv = mock_module.C_Finalize (NULL);
+	assert (rv == CKR_OK);
 }
 
 static void
-test_with_slot (CuTest *tc)
+test_with_slot (void)
 {
 	CK_OBJECT_HANDLE objects[128];
 	CK_FUNCTION_LIST_PTR module;
@@ -337,44 +332,45 @@ test_with_slot (CuTest *tc)
 	CK_RV rv;
 	int at;
 
-	rv = p11_kit_initialize_module (&mock_module);
-	CuAssertTrue (tc, rv == CKR_OK);
+	mock_module_reset ();
+	rv = mock_module.C_Initialize (NULL);
+	assert (rv == CKR_OK);
 
 	iter = p11_kit_iter_new (NULL);
 	p11_kit_iter_begin_with (iter, &mock_module, MOCK_SLOT_ONE_ID, 0);
 
 	at= 0;
 	while ((rv = p11_kit_iter_next (iter)) == CKR_OK) {
-		CuAssertTrue (tc, at < 128);
+		assert (at < 128);
 		objects[at] = p11_kit_iter_get_object (iter);
 
 		slot = p11_kit_iter_get_slot (iter);
-		CuAssertTrue (tc, slot == MOCK_SLOT_ONE_ID);
+		assert (slot == MOCK_SLOT_ONE_ID);
 
 		module = p11_kit_iter_get_module (iter);
-		CuAssertPtrEquals (tc, module, &mock_module);
+		assert_ptr_eq (module, &mock_module);
 		at++;
 	}
 
-	CuAssertTrue (tc, rv == CKR_CANCEL);
+	assert (rv == CKR_CANCEL);
 
 	/* 1 modules, each with 1 slot, and 3 public objects */
-	CuAssertIntEquals (tc, 3, at);
+	assert_num_eq (3, at);
 
-	CuAssertTrue (tc, has_handle (objects, at, MOCK_DATA_OBJECT));
-	CuAssertTrue (tc, !has_handle (objects, at, MOCK_PRIVATE_KEY_CAPITALIZE));
-	CuAssertTrue (tc, has_handle (objects, at, MOCK_PUBLIC_KEY_CAPITALIZE));
-	CuAssertTrue (tc, !has_handle (objects, at, MOCK_PRIVATE_KEY_PREFIX));
-	CuAssertTrue (tc, has_handle (objects, at, MOCK_PUBLIC_KEY_PREFIX));
+	assert (has_handle (objects, at, MOCK_DATA_OBJECT));
+	assert (!has_handle (objects, at, MOCK_PRIVATE_KEY_CAPITALIZE));
+	assert (has_handle (objects, at, MOCK_PUBLIC_KEY_CAPITALIZE));
+	assert (!has_handle (objects, at, MOCK_PRIVATE_KEY_PREFIX));
+	assert (has_handle (objects, at, MOCK_PUBLIC_KEY_PREFIX));
 
 	p11_kit_iter_free (iter);
 
-	rv = p11_kit_finalize_module (&mock_module);
-	CuAssertTrue (tc, rv == CKR_OK);
+	rv = (mock_module.C_Finalize) (NULL);
+	assert (rv == CKR_OK);
 }
 
 static void
-test_with_module (CuTest *tc)
+test_with_module (void)
 {
 	CK_OBJECT_HANDLE objects[128];
 	CK_FUNCTION_LIST_PTR module;
@@ -382,68 +378,70 @@ test_with_module (CuTest *tc)
 	CK_RV rv;
 	int at;
 
-	rv = p11_kit_initialize_module (&mock_module);
-	CuAssertTrue (tc, rv == CKR_OK);
+	mock_module_reset ();
+	rv = mock_module.C_Initialize (NULL);
+	assert (rv == CKR_OK);
 
 	iter = p11_kit_iter_new (NULL);
 	p11_kit_iter_begin_with (iter, &mock_module, 0, 0);
 
 	at= 0;
 	while ((rv = p11_kit_iter_next (iter)) == CKR_OK) {
-		CuAssertTrue (tc, at < 128);
+		assert (at < 128);
 		objects[at] = p11_kit_iter_get_object (iter);
 
 		module = p11_kit_iter_get_module (iter);
-		CuAssertPtrEquals (tc, module, &mock_module);
+		assert_ptr_eq (module, &mock_module);
 		at++;
 	}
 
-	CuAssertTrue (tc, rv == CKR_CANCEL);
+	assert (rv == CKR_CANCEL);
 
 	/* 1 modules, each with 1 slot, and 3 public objects */
-	CuAssertIntEquals (tc, 3, at);
+	assert_num_eq (3, at);
 
-	CuAssertTrue (tc, has_handle (objects, at, MOCK_DATA_OBJECT));
-	CuAssertTrue (tc, !has_handle (objects, at, MOCK_PRIVATE_KEY_CAPITALIZE));
-	CuAssertTrue (tc, has_handle (objects, at, MOCK_PUBLIC_KEY_CAPITALIZE));
-	CuAssertTrue (tc, !has_handle (objects, at, MOCK_PRIVATE_KEY_PREFIX));
-	CuAssertTrue (tc, has_handle (objects, at, MOCK_PUBLIC_KEY_PREFIX));
+	assert (has_handle (objects, at, MOCK_DATA_OBJECT));
+	assert (!has_handle (objects, at, MOCK_PRIVATE_KEY_CAPITALIZE));
+	assert (has_handle (objects, at, MOCK_PUBLIC_KEY_CAPITALIZE));
+	assert (!has_handle (objects, at, MOCK_PRIVATE_KEY_PREFIX));
+	assert (has_handle (objects, at, MOCK_PUBLIC_KEY_PREFIX));
 
 	p11_kit_iter_free (iter);
 
-	rv = p11_kit_finalize_module (&mock_module);
-	CuAssertTrue (tc, rv == CKR_OK);
+	rv = mock_module.C_Finalize (NULL);
+	assert (rv == CKR_OK);
 }
 
 static void
-test_keep_session (CuTest *tc)
+test_keep_session (void)
 {
 	CK_SESSION_HANDLE session;
 	P11KitIter *iter;
 	CK_RV rv;
 
-	rv = p11_kit_initialize_module (&mock_module);
-	CuAssertTrue (tc, rv == CKR_OK);
+	mock_module_reset ();
+	rv = mock_module.C_Initialize (NULL);
+	assert (rv == CKR_OK);
 
 	iter = p11_kit_iter_new (NULL);
 	p11_kit_iter_begin_with (iter, &mock_module, 0, 0);
 
 	rv = p11_kit_iter_next (iter);
-	CuAssertTrue (tc, rv == CKR_OK);
+	assert (rv == CKR_OK);
 
 	session = p11_kit_iter_keep_session (iter);
 	p11_kit_iter_free (iter);
 
 	/* The session is still valid ... */
 	rv = mock_module.C_CloseSession (session);
-	CuAssertTrue (tc, rv == CKR_OK);
+	assert (rv == CKR_OK);
 
-	rv = p11_kit_finalize_module (&mock_module);
-	CuAssertTrue (tc, rv == CKR_OK);
+	rv = mock_module.C_Finalize (NULL);
+	assert (rv == CKR_OK);
 }
 
 static void
-test_unrecognized (CuTest *tc)
+test_unrecognized (void)
 {
 	CK_FUNCTION_LIST_PTR *modules;
 	P11KitIter *iter;
@@ -451,7 +449,7 @@ test_unrecognized (CuTest *tc)
 	CK_RV rv;
 	int count;
 
-	modules = initialize_and_get_modules (tc);
+	modules = initialize_and_get_modules ();
 
 	uri = p11_kit_uri_new ();
 	p11_kit_uri_set_unrecognized (uri, 1);
@@ -464,18 +462,18 @@ test_unrecognized (CuTest *tc)
 	while ((rv = p11_kit_iter_next (iter)) == CKR_OK)
 		count++;
 
-	CuAssertTrue (tc, rv == CKR_CANCEL);
+	assert (rv == CKR_CANCEL);
 
 	/* Nothing should have matched */
-	CuAssertIntEquals (tc, 0, count);
+	assert_num_eq (0, count);
 
 	p11_kit_iter_free (iter);
 
-	finalize_and_free_modules (tc, modules);
+	finalize_and_free_modules (modules);
 }
 
 static void
-test_uri_with_type (CuTest *tc)
+test_uri_with_type (void)
 {
 	CK_OBJECT_HANDLE objects[128];
 	CK_FUNCTION_LIST_PTR *modules;
@@ -485,11 +483,11 @@ test_uri_with_type (CuTest *tc)
 	int at;
 	int ret;
 
-	modules = initialize_and_get_modules (tc);
+	modules = initialize_and_get_modules ();
 
 	uri = p11_kit_uri_new ();
 	ret = p11_kit_uri_parse ("pkcs11:object-type=public", P11_KIT_URI_FOR_OBJECT, uri);
-	CuAssertIntEquals (tc, ret, P11_KIT_URI_OK);
+	assert_num_eq (ret, P11_KIT_URI_OK);
 
 	iter = p11_kit_iter_new (uri);
 	p11_kit_uri_free (uri);
@@ -498,29 +496,29 @@ test_uri_with_type (CuTest *tc)
 
 	at = 0;
 	while ((rv = p11_kit_iter_next (iter)) == CKR_OK) {
-		CuAssertTrue (tc, at < 128);
+		assert (at < 128);
 		objects[at] = p11_kit_iter_get_object (iter);
 		at++;
 	}
 
-	CuAssertTrue (tc, rv == CKR_CANCEL);
+	assert (rv == CKR_CANCEL);
 
 	/* Three modules, each with 1 slot, and 2 public keys */
-	CuAssertIntEquals (tc, 6, at);
+	assert_num_eq (6, at);
 
-	CuAssertTrue (tc, !has_handle (objects, at, MOCK_DATA_OBJECT));
-	CuAssertTrue (tc, !has_handle (objects, at, MOCK_PRIVATE_KEY_CAPITALIZE));
-	CuAssertTrue (tc, has_handle (objects, at, MOCK_PUBLIC_KEY_CAPITALIZE));
-	CuAssertTrue (tc, !has_handle (objects, at, MOCK_PRIVATE_KEY_PREFIX));
-	CuAssertTrue (tc, has_handle (objects, at, MOCK_PUBLIC_KEY_PREFIX));
+	assert (!has_handle (objects, at, MOCK_DATA_OBJECT));
+	assert (!has_handle (objects, at, MOCK_PRIVATE_KEY_CAPITALIZE));
+	assert (has_handle (objects, at, MOCK_PUBLIC_KEY_CAPITALIZE));
+	assert (!has_handle (objects, at, MOCK_PRIVATE_KEY_PREFIX));
+	assert (has_handle (objects, at, MOCK_PUBLIC_KEY_PREFIX));
 
 	p11_kit_iter_free (iter);
 
-	finalize_and_free_modules (tc, modules);
+	finalize_and_free_modules (modules);
 }
 
 static void
-test_filter (CuTest *tc)
+test_filter (void)
 {
 	CK_OBJECT_HANDLE objects[128];
 	CK_FUNCTION_LIST_PTR *modules;
@@ -535,7 +533,7 @@ test_filter (CuTest *tc)
 		{ CKA_CLASS, &public_key, sizeof (public_key) },
 	};
 
-	modules = initialize_and_get_modules (tc);
+	modules = initialize_and_get_modules ();
 
 	iter = p11_kit_iter_new (NULL);
 	p11_kit_iter_add_filter (iter, attrs, 2);
@@ -544,29 +542,29 @@ test_filter (CuTest *tc)
 
 	at = 0;
 	while ((rv = p11_kit_iter_next (iter)) == CKR_OK) {
-		CuAssertTrue (tc, at < 128);
+		assert (at < 128);
 		objects[at] = p11_kit_iter_get_object (iter);
 		at++;
 	}
 
-	CuAssertTrue (tc, rv == CKR_CANCEL);
+	assert (rv == CKR_CANCEL);
 
 	/* Three modules, each with 1 slot, and 2 public keys */
-	CuAssertIntEquals (tc, 6, at);
+	assert_num_eq (6, at);
 
-	CuAssertTrue (tc, !has_handle (objects, at, MOCK_DATA_OBJECT));
-	CuAssertTrue (tc, !has_handle (objects, at, MOCK_PRIVATE_KEY_CAPITALIZE));
-	CuAssertTrue (tc, has_handle (objects, at, MOCK_PUBLIC_KEY_CAPITALIZE));
-	CuAssertTrue (tc, !has_handle (objects, at, MOCK_PRIVATE_KEY_PREFIX));
-	CuAssertTrue (tc, has_handle (objects, at, MOCK_PUBLIC_KEY_PREFIX));
+	assert (!has_handle (objects, at, MOCK_DATA_OBJECT));
+	assert (!has_handle (objects, at, MOCK_PRIVATE_KEY_CAPITALIZE));
+	assert (has_handle (objects, at, MOCK_PUBLIC_KEY_CAPITALIZE));
+	assert (!has_handle (objects, at, MOCK_PRIVATE_KEY_PREFIX));
+	assert (has_handle (objects, at, MOCK_PUBLIC_KEY_PREFIX));
 
 	p11_kit_iter_free (iter);
 
-	finalize_and_free_modules (tc, modules);
+	finalize_and_free_modules (modules);
 }
 
 static void
-test_session_flags (CuTest *tc)
+test_session_flags (void)
 {
 	CK_FUNCTION_LIST_PTR *modules;
 	CK_FUNCTION_LIST_PTR module;
@@ -575,7 +573,7 @@ test_session_flags (CuTest *tc)
 	P11KitIter *iter;
 	CK_RV rv;
 
-	modules = initialize_and_get_modules (tc);
+	modules = initialize_and_get_modules ();
 
 	iter = p11_kit_iter_new (NULL);
 	p11_kit_iter_set_session_flags (iter, CKF_RW_SESSION);
@@ -584,26 +582,26 @@ test_session_flags (CuTest *tc)
 
 	while ((rv = p11_kit_iter_next (iter)) == CKR_OK) {
 		module = p11_kit_iter_get_module (iter);
-		CuAssertPtrNotNull (tc, module);
+		assert_ptr_not_null (module);
 
 		session = p11_kit_iter_get_session (iter);
-		CuAssertTrue (tc, session != 0);
+		assert (session != 0);
 
 		rv = (module->C_GetSessionInfo) (session, &info);
-		CuAssertTrue (tc, rv == CKR_OK);
+		assert (rv == CKR_OK);
 
-		CuAssertIntEquals (tc, CKS_RW_PUBLIC_SESSION, info.state);
+		assert_num_eq (CKS_RW_PUBLIC_SESSION, info.state);
 	}
 
-	CuAssertTrue (tc, rv == CKR_CANCEL);
+	assert (rv == CKR_CANCEL);
 
 	p11_kit_iter_free (iter);
 
-	finalize_and_free_modules (tc, modules);
+	finalize_and_free_modules (modules);
 }
 
 static void
-test_module_match (CuTest *tc)
+test_module_match (void)
 {
 	CK_FUNCTION_LIST_PTR *modules;
 	P11KitIter *iter;
@@ -612,11 +610,11 @@ test_module_match (CuTest *tc)
 	int count;
 	int ret;
 
-	modules = initialize_and_get_modules (tc);
+	modules = initialize_and_get_modules ();
 
 	uri = p11_kit_uri_new ();
 	ret = p11_kit_uri_parse ("pkcs11:library-description=MOCK%20LIBRARY", P11_KIT_URI_FOR_MODULE, uri);
-	CuAssertIntEquals (tc, P11_KIT_URI_OK, ret);
+	assert_num_eq (P11_KIT_URI_OK, ret);
 
 	iter = p11_kit_iter_new (uri);
 	p11_kit_uri_free (uri);
@@ -627,18 +625,18 @@ test_module_match (CuTest *tc)
 	while ((rv = p11_kit_iter_next (iter)) == CKR_OK)
 		count++;
 
-	CuAssertTrue (tc, rv == CKR_CANCEL);
+	assert (rv == CKR_CANCEL);
 
 	/* Three modules, each with 1 slot, and 3 public objects */
-	CuAssertIntEquals (tc, 9, count);
+	assert_num_eq (9, count);
 
 	p11_kit_iter_free (iter);
 
-	finalize_and_free_modules (tc, modules);
+	finalize_and_free_modules (modules);
 }
 
 static void
-test_module_mismatch (CuTest *tc)
+test_module_mismatch (void)
 {
 	CK_FUNCTION_LIST_PTR *modules;
 	P11KitIter *iter;
@@ -647,11 +645,11 @@ test_module_mismatch (CuTest *tc)
 	int count;
 	int ret;
 
-	modules = initialize_and_get_modules (tc);
+	modules = initialize_and_get_modules ();
 
 	uri = p11_kit_uri_new ();
 	ret = p11_kit_uri_parse ("pkcs11:library-description=blah", P11_KIT_URI_FOR_MODULE, uri);
-	CuAssertIntEquals (tc, P11_KIT_URI_OK, ret);
+	assert_num_eq (P11_KIT_URI_OK, ret);
 
 	iter = p11_kit_iter_new (uri);
 	p11_kit_uri_free (uri);
@@ -662,18 +660,18 @@ test_module_mismatch (CuTest *tc)
 	while ((rv = p11_kit_iter_next (iter)) == CKR_OK)
 		count++;
 
-	CuAssertTrue (tc, rv == CKR_CANCEL);
+	assert (rv == CKR_CANCEL);
 
 	/* Nothing should have matched */
-	CuAssertIntEquals (tc, 0, count);
+	assert_num_eq (0, count);
 
 	p11_kit_iter_free (iter);
 
-	finalize_and_free_modules (tc, modules);
+	finalize_and_free_modules (modules);
 }
 
 static void
-test_token_match (CuTest *tc)
+test_token_match (void)
 {
 	CK_FUNCTION_LIST_PTR *modules;
 	P11KitIter *iter;
@@ -682,11 +680,11 @@ test_token_match (CuTest *tc)
 	int count;
 	int ret;
 
-	modules = initialize_and_get_modules (tc);
+	modules = initialize_and_get_modules ();
 
 	uri = p11_kit_uri_new ();
 	ret = p11_kit_uri_parse ("pkcs11:manufacturer=TEST%20MANUFACTURER", P11_KIT_URI_FOR_TOKEN, uri);
-	CuAssertIntEquals (tc, P11_KIT_URI_OK, ret);
+	assert_num_eq (P11_KIT_URI_OK, ret);
 
 	iter = p11_kit_iter_new (uri);
 	p11_kit_uri_free (uri);
@@ -697,18 +695,18 @@ test_token_match (CuTest *tc)
 	while ((rv = p11_kit_iter_next (iter)) == CKR_OK)
 		count++;
 
-	CuAssertTrue (tc, rv == CKR_CANCEL);
+	assert (rv == CKR_CANCEL);
 
 	/* Three modules, each with 1 slot, and 3 public objects */
-	CuAssertIntEquals (tc, 9, count);
+	assert_num_eq (9, count);
 
 	p11_kit_iter_free (iter);
 
-	finalize_and_free_modules (tc, modules);
+	finalize_and_free_modules (modules);
 }
 
 static void
-test_token_mismatch (CuTest *tc)
+test_token_mismatch (void)
 {
 	CK_FUNCTION_LIST_PTR *modules;
 	P11KitIter *iter;
@@ -717,11 +715,11 @@ test_token_mismatch (CuTest *tc)
 	int count;
 	int ret;
 
-	modules = initialize_and_get_modules (tc);
+	modules = initialize_and_get_modules ();
 
 	uri = p11_kit_uri_new ();
 	ret = p11_kit_uri_parse ("pkcs11:manufacturer=blah", P11_KIT_URI_FOR_TOKEN, uri);
-	CuAssertIntEquals (tc, P11_KIT_URI_OK, ret);
+	assert_num_eq (P11_KIT_URI_OK, ret);
 
 	iter = p11_kit_iter_new (uri);
 	p11_kit_uri_free (uri);
@@ -732,26 +730,27 @@ test_token_mismatch (CuTest *tc)
 	while ((rv = p11_kit_iter_next (iter)) == CKR_OK)
 		count++;
 
-	CuAssertTrue (tc, rv == CKR_CANCEL);
+	assert (rv == CKR_CANCEL);
 
 	/* Nothing should have matched */
-	CuAssertIntEquals (tc, 0, count);
+	assert_num_eq (0, count);
 
 	p11_kit_iter_free (iter);
 
-	finalize_and_free_modules (tc, modules);
+	finalize_and_free_modules (modules);
 }
 
 static void
-test_getslotlist_fail_first (CuTest *tc)
+test_getslotlist_fail_first (void)
 {
 	CK_FUNCTION_LIST module;
 	P11KitIter *iter;
 	CK_RV rv;
 	int at;
 
-	rv = p11_kit_initialize_module (&mock_module);
-	CuAssertTrue (tc, rv == CKR_OK);
+	mock_module_reset ();
+	rv = mock_module.C_Initialize (NULL);
+	assert (rv == CKR_OK);
 
 	memcpy (&module, &mock_module, sizeof (CK_FUNCTION_LIST));
 	module.C_GetSlotList = mock_C_GetSlotList__fail_first;
@@ -763,27 +762,28 @@ test_getslotlist_fail_first (CuTest *tc)
 	while ((rv = p11_kit_iter_next (iter)) == CKR_OK)
 		at++;
 
-	CuAssertTrue (tc, rv == CKR_VENDOR_DEFINED);
+	assert (rv == CKR_VENDOR_DEFINED);
 
 	/* Should fail on the first iteration */
-	CuAssertIntEquals (tc, 0, at);
+	assert_num_eq (0, at);
 
 	p11_kit_iter_free (iter);
 
-	rv = p11_kit_finalize_module (&mock_module);
-	CuAssertTrue (tc, rv == CKR_OK);
+	rv = mock_module.C_Finalize (NULL);
+	assert (rv == CKR_OK);
 }
 
 static void
-test_getslotlist_fail_late (CuTest *tc)
+test_getslotlist_fail_late (void)
 {
 	CK_FUNCTION_LIST module;
 	P11KitIter *iter;
 	CK_RV rv;
 	int at;
 
-	rv = p11_kit_initialize_module (&mock_module);
-	CuAssertTrue (tc, rv == CKR_OK);
+	mock_module_reset ();
+	rv = mock_module.C_Initialize (NULL);
+	assert (rv == CKR_OK);
 
 	memcpy (&module, &mock_module, sizeof (CK_FUNCTION_LIST));
 	module.C_GetSlotList = mock_C_GetSlotList__fail_late;
@@ -795,27 +795,28 @@ test_getslotlist_fail_late (CuTest *tc)
 	while ((rv = p11_kit_iter_next (iter)) == CKR_OK)
 		at++;
 
-	CuAssertTrue (tc, rv == CKR_VENDOR_DEFINED);
+	assert (rv == CKR_VENDOR_DEFINED);
 
 	/* Should fail on the first iteration */
-	CuAssertIntEquals (tc, 0, at);
+	assert_num_eq (0, at);
 
 	p11_kit_iter_free (iter);
 
-	rv = p11_kit_finalize_module (&mock_module);
-	CuAssertTrue (tc, rv == CKR_OK);
+	rv = mock_module.C_Finalize (NULL);
+	assert (rv == CKR_OK);
 }
 
 static void
-test_open_session_fail (CuTest *tc)
+test_open_session_fail (void)
 {
 	CK_FUNCTION_LIST module;
 	P11KitIter *iter;
 	CK_RV rv;
 	int at;
 
-	rv = p11_kit_initialize_module (&mock_module);
-	CuAssertTrue (tc, rv == CKR_OK);
+	mock_module_reset ();
+	rv = mock_module.C_Initialize (NULL);
+	assert (rv == CKR_OK);
 
 	memcpy (&module, &mock_module, sizeof (CK_FUNCTION_LIST));
 	module.C_OpenSession = mock_C_OpenSession__fails;
@@ -827,27 +828,28 @@ test_open_session_fail (CuTest *tc)
 	while ((rv = p11_kit_iter_next (iter)) == CKR_OK)
 		at++;
 
-	CuAssertTrue (tc, rv == CKR_DEVICE_ERROR);
+	assert (rv == CKR_DEVICE_ERROR);
 
 	/* Should fail on the first iteration */
-	CuAssertIntEquals (tc, 0, at);
+	assert_num_eq (0, at);
 
 	p11_kit_iter_free (iter);
 
-	rv = p11_kit_finalize_module (&mock_module);
-	CuAssertTrue (tc, rv == CKR_OK);
+	rv = mock_module.C_Finalize (NULL);
+	assert (rv == CKR_OK);
 }
 
 static void
-test_find_init_fail (CuTest *tc)
+test_find_init_fail (void)
 {
 	CK_FUNCTION_LIST module;
 	P11KitIter *iter;
 	CK_RV rv;
 	int at;
 
-	rv = p11_kit_initialize_module (&mock_module);
-	CuAssertTrue (tc, rv == CKR_OK);
+	mock_module_reset ();
+	rv = mock_module.C_Initialize (NULL);
+	assert (rv == CKR_OK);
 
 	memcpy (&module, &mock_module, sizeof (CK_FUNCTION_LIST));
 	module.C_FindObjectsInit = mock_C_FindObjectsInit__fails;
@@ -859,27 +861,28 @@ test_find_init_fail (CuTest *tc)
 	while ((rv = p11_kit_iter_next (iter)) == CKR_OK)
 		at++;
 
-	CuAssertTrue (tc, rv == CKR_DEVICE_MEMORY);
+	assert (rv == CKR_DEVICE_MEMORY);
 
 	/* Should fail on the first iteration */
-	CuAssertIntEquals (tc, 0, at);
+	assert_num_eq (0, at);
 
 	p11_kit_iter_free (iter);
 
-	rv = p11_kit_finalize_module (&mock_module);
-	CuAssertTrue (tc, rv == CKR_OK);
+	rv = mock_module.C_Finalize (NULL);
+	assert (rv == CKR_OK);
 }
 
 static void
-test_find_objects_fail (CuTest *tc)
+test_find_objects_fail (void)
 {
 	CK_FUNCTION_LIST module;
 	P11KitIter *iter;
 	CK_RV rv;
 	int at;
 
-	rv = p11_kit_initialize_module (&mock_module);
-	CuAssertTrue (tc, rv == CKR_OK);
+	mock_module_reset ();
+	rv = mock_module.C_Initialize (NULL);
+	assert (rv == CKR_OK);
 
 	memcpy (&module, &mock_module, sizeof (CK_FUNCTION_LIST));
 	module.C_FindObjects = mock_C_FindObjects__fails;
@@ -891,19 +894,19 @@ test_find_objects_fail (CuTest *tc)
 	while ((rv = p11_kit_iter_next (iter)) == CKR_OK)
 		at++;
 
-	CuAssertTrue (tc, rv == CKR_DEVICE_REMOVED);
+	assert (rv == CKR_DEVICE_REMOVED);
 
 	/* Should fail on the first iteration */
-	CuAssertIntEquals (tc, 0, at);
+	assert_num_eq (0, at);
 
 	p11_kit_iter_free (iter);
 
-	rv = p11_kit_finalize_module (&mock_module);
-	CuAssertTrue (tc, rv == CKR_OK);
+	rv = mock_module.C_Finalize (NULL);
+	assert (rv == CKR_OK);
 }
 
 static void
-test_load_attributes (CuTest *tc)
+test_load_attributes (void)
 {
 	CK_FUNCTION_LIST_PTR *modules;
 	P11KitIter *iter;
@@ -918,7 +921,7 @@ test_load_attributes (CuTest *tc)
 		{ CKA_LABEL },
 	};
 
-	modules = initialize_and_get_modules (tc);
+	modules = initialize_and_get_modules ();
 
 	iter = p11_kit_iter_new (NULL);
 	p11_kit_iter_begin (iter, modules);
@@ -928,24 +931,24 @@ test_load_attributes (CuTest *tc)
 	at = 0;
 	while ((rv = p11_kit_iter_next (iter)) == CKR_OK) {
 		rv = p11_kit_iter_load_attributes (iter, attrs, 2);
-		CuAssertTrue (tc, rv == CKR_OK);
+		assert (rv == CKR_OK);
 
 		object = p11_kit_iter_get_object (iter);
 		switch (object) {
 		case MOCK_DATA_OBJECT:
-			CuAssertTrue (tc, p11_attrs_find_ulong (attrs, CKA_CLASS, &ulong) && ulong == CKO_DATA);
-			CuAssertTrue (tc, p11_attr_match_value (p11_attrs_find (attrs, CKA_LABEL), "TEST LABEL", -1));
+			assert (p11_attrs_find_ulong (attrs, CKA_CLASS, &ulong) && ulong == CKO_DATA);
+			assert (p11_attr_match_value (p11_attrs_find (attrs, CKA_LABEL), "TEST LABEL", -1));
 			break;
 		case MOCK_PUBLIC_KEY_CAPITALIZE:
-			CuAssertTrue (tc, p11_attrs_find_ulong (attrs, CKA_CLASS, &ulong) && ulong == CKO_PUBLIC_KEY);
-			CuAssertTrue (tc, p11_attr_match_value (p11_attrs_find (attrs, CKA_LABEL), "Public Capitalize Key", -1));
+			assert (p11_attrs_find_ulong (attrs, CKA_CLASS, &ulong) && ulong == CKO_PUBLIC_KEY);
+			assert (p11_attr_match_value (p11_attrs_find (attrs, CKA_LABEL), "Public Capitalize Key", -1));
 			break;
 		case MOCK_PUBLIC_KEY_PREFIX:
-			CuAssertTrue (tc, p11_attrs_find_ulong (attrs, CKA_CLASS, &ulong) && ulong == CKO_PUBLIC_KEY);
-			CuAssertTrue (tc, p11_attr_match_value (p11_attrs_find (attrs, CKA_LABEL), "Public prefix key", -1));
+			assert (p11_attrs_find_ulong (attrs, CKA_CLASS, &ulong) && ulong == CKO_PUBLIC_KEY);
+			assert (p11_attr_match_value (p11_attrs_find (attrs, CKA_LABEL), "Public prefix key", -1));
 			break;
 		default:
-			CuFail (tc, "Unknown object matched");
+			assert_fail ("Unknown object matched", NULL);
 			break;
 		}
 
@@ -954,26 +957,27 @@ test_load_attributes (CuTest *tc)
 
 	p11_attrs_free (attrs);
 
-	CuAssertTrue (tc, rv == CKR_CANCEL);
+	assert (rv == CKR_CANCEL);
 
 	/* Three modules, each with 1 slot, and 3 public objects */
-	CuAssertIntEquals (tc, 9, at);
+	assert_num_eq (9, at);
 
 	p11_kit_iter_free (iter);
 
-	finalize_and_free_modules (tc, modules);
+	finalize_and_free_modules (modules);
 }
 
 static void
-test_load_attributes_none (CuTest *tc)
+test_load_attributes_none (void)
 {
 	CK_FUNCTION_LIST module;
 	P11KitIter *iter;
 	CK_ATTRIBUTE *attrs;
 	CK_RV rv;
 
-	rv = p11_kit_initialize_module (&mock_module);
-	CuAssertTrue (tc, rv == CKR_OK);
+	mock_module_reset ();
+	rv = mock_module.C_Initialize (NULL);
+	assert (rv == CKR_OK);
 
 	memcpy (&module, &mock_module, sizeof (CK_FUNCTION_LIST));
 
@@ -983,20 +987,20 @@ test_load_attributes_none (CuTest *tc)
 	while ((rv = p11_kit_iter_next (iter)) == CKR_OK) {
 		attrs = p11_attrs_buildn (NULL, NULL, 0);
 		rv = p11_kit_iter_load_attributes (iter, attrs, 0);
-		CuAssertTrue (tc, rv == CKR_OK);
+		assert (rv == CKR_OK);
 		p11_attrs_free (attrs);
 	}
 
-	CuAssertTrue (tc, rv == CKR_CANCEL);
+	assert (rv == CKR_CANCEL);
 
 	p11_kit_iter_free (iter);
 
-	rv = p11_kit_finalize_module (&mock_module);
-	CuAssertTrue (tc, rv == CKR_OK);
+	rv = mock_module.C_Finalize (NULL);
+	assert (rv == CKR_OK);
 }
 
 static void
-test_load_attributes_fail_first (CuTest *tc)
+test_load_attributes_fail_first (void)
 {
 	CK_ATTRIBUTE label = { CKA_LABEL, };
 	CK_FUNCTION_LIST module;
@@ -1004,8 +1008,9 @@ test_load_attributes_fail_first (CuTest *tc)
 	CK_ATTRIBUTE *attrs;
 	CK_RV rv;
 
-	rv = p11_kit_initialize_module (&mock_module);
-	CuAssertTrue (tc, rv == CKR_OK);
+	mock_module_reset ();
+	rv = mock_module.C_Initialize (NULL);
+	assert (rv == CKR_OK);
 
 	memcpy (&module, &mock_module, sizeof (CK_FUNCTION_LIST));
 	module.C_GetAttributeValue = mock_C_GetAttributeValue__fail_first;
@@ -1016,20 +1021,20 @@ test_load_attributes_fail_first (CuTest *tc)
 	while ((rv = p11_kit_iter_next (iter)) == CKR_OK) {
 		attrs = p11_attrs_build (NULL, &label, NULL);
 		rv = p11_kit_iter_load_attributes (iter, attrs, 1);
-		CuAssertTrue (tc, rv == CKR_FUNCTION_REJECTED);
+		assert (rv == CKR_FUNCTION_REJECTED);
 		p11_attrs_free (attrs);
 	}
 
-	CuAssertTrue (tc, rv == CKR_CANCEL);
+	assert (rv == CKR_CANCEL);
 
 	p11_kit_iter_free (iter);
 
-	rv = p11_kit_finalize_module (&mock_module);
-	CuAssertTrue (tc, rv == CKR_OK);
+	rv = mock_module.C_Finalize (NULL);
+	assert (rv == CKR_OK);
 }
 
 static void
-test_load_attributes_fail_late (CuTest *tc)
+test_load_attributes_fail_late (void)
 {
 	CK_ATTRIBUTE label = { CKA_LABEL, };
 	CK_FUNCTION_LIST module;
@@ -1037,8 +1042,9 @@ test_load_attributes_fail_late (CuTest *tc)
 	CK_ATTRIBUTE *attrs;
 	CK_RV rv;
 
-	rv = p11_kit_initialize_module (&mock_module);
-	CuAssertTrue (tc, rv == CKR_OK);
+	mock_module_reset ();
+	rv = mock_module.C_Initialize (NULL);
+	assert (rv == CKR_OK);
 
 	memcpy (&module, &mock_module, sizeof (CK_FUNCTION_LIST));
 	module.C_GetAttributeValue = mock_C_GetAttributeValue__fail_late;
@@ -1049,61 +1055,50 @@ test_load_attributes_fail_late (CuTest *tc)
 	while ((rv = p11_kit_iter_next (iter)) == CKR_OK) {
 		attrs = p11_attrs_build (NULL, &label, NULL);
 		rv = p11_kit_iter_load_attributes (iter, attrs, 1);
-		CuAssertTrue (tc, rv == CKR_FUNCTION_FAILED);
+		assert (rv == CKR_FUNCTION_FAILED);
 		p11_attrs_free (attrs);
 	}
 
-	CuAssertTrue (tc, rv == CKR_CANCEL);
+	assert (rv == CKR_CANCEL);
 
 	p11_kit_iter_free (iter);
 
-	rv = p11_kit_finalize_module (&mock_module);
-	CuAssertTrue (tc, rv == CKR_OK);
+	rv = mock_module.C_Finalize (NULL);
+	assert (rv == CKR_OK);
 }
 
 int
-main (void)
+main (int argc,
+      char *argv[])
 {
-	CuString *output = CuStringNew ();
-	CuSuite* suite = CuSuiteNew ();
-	int ret;
-
-	putenv ("P11_KIT_STRICT=1");
 	p11_library_init ();
 	mock_module_init ();
 
-	SUITE_ADD_TEST (suite, test_all);
-	SUITE_ADD_TEST (suite, test_unrecognized);
-	SUITE_ADD_TEST (suite, test_uri_with_type);
-	SUITE_ADD_TEST (suite, test_session_flags);
-	SUITE_ADD_TEST (suite, test_callback);
-	SUITE_ADD_TEST (suite, test_callback_fails);
-	SUITE_ADD_TEST (suite, test_callback_destroyer);
-	SUITE_ADD_TEST (suite, test_filter);
-	SUITE_ADD_TEST (suite, test_with_session);
-	SUITE_ADD_TEST (suite, test_with_slot);
-	SUITE_ADD_TEST (suite, test_with_module);
-	SUITE_ADD_TEST (suite, test_keep_session);
-	SUITE_ADD_TEST (suite, test_token_match);
-	SUITE_ADD_TEST (suite, test_token_mismatch);
-	SUITE_ADD_TEST (suite, test_module_match);
-	SUITE_ADD_TEST (suite, test_module_mismatch);
-	SUITE_ADD_TEST (suite, test_getslotlist_fail_first);
-	SUITE_ADD_TEST (suite, test_getslotlist_fail_late);
-	SUITE_ADD_TEST (suite, test_open_session_fail);
-	SUITE_ADD_TEST (suite, test_find_init_fail);
-	SUITE_ADD_TEST (suite, test_find_objects_fail);
-	SUITE_ADD_TEST (suite, test_load_attributes);
-	SUITE_ADD_TEST (suite, test_load_attributes_none);
-	SUITE_ADD_TEST (suite, test_load_attributes_fail_first);
-	SUITE_ADD_TEST (suite, test_load_attributes_fail_late);
+	p11_test (test_all, "/iter/test_all");
+	p11_test (test_unrecognized, "/iter/test_unrecognized");
+	p11_test (test_uri_with_type, "/iter/test_uri_with_type");
+	p11_test (test_session_flags, "/iter/test_session_flags");
+	p11_test (test_callback, "/iter/test_callback");
+	p11_test (test_callback_fails, "/iter/test_callback_fails");
+	p11_test (test_callback_destroyer, "/iter/test_callback_destroyer");
+	p11_test (test_filter, "/iter/test_filter");
+	p11_test (test_with_session, "/iter/test_with_session");
+	p11_test (test_with_slot, "/iter/test_with_slot");
+	p11_test (test_with_module, "/iter/test_with_module");
+	p11_test (test_keep_session, "/iter/test_keep_session");
+	p11_test (test_token_match, "/iter/test_token_match");
+	p11_test (test_token_mismatch, "/iter/test_token_mismatch");
+	p11_test (test_module_match, "/iter/test_module_match");
+	p11_test (test_module_mismatch, "/iter/test_module_mismatch");
+	p11_test (test_getslotlist_fail_first, "/iter/test_getslotlist_fail_first");
+	p11_test (test_getslotlist_fail_late, "/iter/test_getslotlist_fail_late");
+	p11_test (test_open_session_fail, "/iter/test_open_session_fail");
+	p11_test (test_find_init_fail, "/iter/test_find_init_fail");
+	p11_test (test_find_objects_fail, "/iter/test_find_objects_fail");
+	p11_test (test_load_attributes, "/iter/test_load_attributes");
+	p11_test (test_load_attributes_none, "/iter/test_load_attributes_none");
+	p11_test (test_load_attributes_fail_first, "/iter/test_load_attributes_fail_first");
+	p11_test (test_load_attributes_fail_late, "/iter/test_load_attributes_fail_late");
 
-	CuSuiteRun (suite);
-	CuSuiteSummary (suite, output);
-	CuSuiteDetails (suite, output);
-	printf ("%s\n", output->buffer);
-	ret = suite->failCount;
-	CuSuiteDelete (suite);
-	CuStringDelete (output);
-	return ret;
+	return p11_test_run (argc, argv);
 }
