@@ -38,7 +38,7 @@
 #define P11_DEBUG_FLAG P11_DEBUG_TRUST
 #include "debug.h"
 #include "dict.h"
-#include "library.h"
+#include "message.h"
 #include "pkcs11.h"
 #include "module.h"
 #include "session.h"
